==> mysql-workbench-gpl-5.2.29-src.tar.gz: mysql-workbench-gpl-5.2.29-src/library/forms/gtk/src/lf_button.cpp <==
/* 
 * © 2008-2009 Sun Microsystems, Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
#include "mforms/button.h"

//#include "../lf_view.h"
#include "../lf_button.h"


mforms::gtk::ButtonImpl::ButtonImpl(::mforms::Button *self, ::mforms::ButtonType btype, bool concrete)
    : ViewImpl(self), _button(0), _align(0), _label(0), _icon(0)
{
  if (concrete)
  {
    _button= Gtk::manage(new Gtk::Button());
    _align= Gtk::manage(new Gtk::Alignment());
    if (btype == ::mforms::PushButton)
    {
      _label= Gtk::manage(new Gtk::Label());
      _align->add(*_label);
    }
    else
    {
      _icon= Gtk::manage(new Gtk::Image());
      _align->add(*_icon);
      _button->set_relief(Gtk::RELIEF_NONE);
    }
    _button->add(*_align);
    _button->signal_clicked().connect(sigc::bind(sigc::ptr_fun(&ButtonImpl::callback), self));

    _button->show_all();
    setup();
  }
}

void mforms::gtk::ButtonImpl::callback(::mforms::Button* self)
{
  self->callback();
}

bool mforms::gtk::ButtonImpl::create(::mforms::Button *self, ::mforms::ButtonType btype)
{
  return new ButtonImpl(self, btype, true) != 0;
}

void mforms::gtk::ButtonImpl::set_text(::mforms::Button *self, const std::string &text)
{
  if ( self )
  {
    ButtonImpl* button = self->get_data<ButtonImpl>();

    if ( button )
    {
      if (button->_label)
        button->_label->set_label(text);
      else
        button->_button->set_label(text);
    }
  }
}

void mforms::gtk::ButtonImpl::set_icon(::mforms::Button *self, const std::string &path)
{
  if ( self )
  {
    ButtonImpl* button = self->get_data<ButtonImpl>();

    if ( button )
    {
      if (button->_icon)
        button->_icon->set(path);
    }
  }
}



void mforms::gtk::ButtonImpl::enable_internal_padding(Button *self, bool enabled)
{
  ButtonImpl* button = self->get_data<ButtonImpl>();
  if (button)
  {
    if (enabled)
      button->_align->set_padding(0, 0, 8, 8);
    else
      button->_align->set_padding(0, 0, 0, 0);
  }
}

void mforms::gtk::ButtonImpl::init()
{
  ::mforms::ControlFactory *f = ::mforms::ControlFactory::get_instance();

  f->_button_impl.create= &ButtonImpl::create;
  f->_button_impl.set_text= &ButtonImpl::set_text;
  f->_button_impl.set_icon= &ButtonImpl::set_icon;
  f->_button_impl.enable_internal_padding= &ButtonImpl::enable_internal_padding;
}

==> mysql-workbench-gpl-5.2.35-src.tar.gz: mysql-workbench-gpl-5.2.35-src/library/forms/gtk/src/lf_button.cpp <==
/* 
 * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; version 2 of the
 * License.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
#include "mforms/button.h"

//#include "../lf_view.h"
#include "../lf_button.h"


mforms::gtk::ButtonImpl::ButtonImpl(::mforms::Button *self, ::mforms::ButtonType btype, bool concrete)
    : ViewImpl(self), _button(0), _align(0), _label(0), _icon(0)
{
  if (concrete)
  {
    _button= Gtk::manage(new Gtk::Button());
    _align= Gtk::manage(new Gtk::Alignment());
    if (btype == ::mforms::PushButton)
    {
      _label= Gtk::manage(new Gtk::Label());
      _align->add(*_label);
    }
    else
    {
      _icon= Gtk::manage(new Gtk::Image());
      _align->add(*_icon);
      _button->set_relief(Gtk::RELIEF_NONE);
    }
    _button->add(*_align);
    _button->signal_clicked().connect(sigc::bind(sigc::ptr_fun(&ButtonImpl::callback), self));

    _button->show_all();
    setup();
  }
}

void mforms::gtk::ButtonImpl::callback(::mforms::Button* self)
{
  self->callback();
}

bool mforms::gtk::ButtonImpl::create(::mforms::Button *self, ::mforms::ButtonType btype)
{
  return new ButtonImpl(self, btype, true) != 0;
}

void mforms::gtk::ButtonImpl::set_text(::mforms::Button *self, const std::string &text)
{
  if ( self )
  {
    ButtonImpl* button = self->get_data<ButtonImpl>();

    if ( button )
    {
      if (button->_label)
        button->_label->set_label(text);
      else
        button->_button->set_label(text);
    }
  }
}

void mforms::gtk::ButtonImpl::set_icon(::mforms::Button *self, const std::string &path)
{
  if ( self )
  {
    ButtonImpl* button = self->get_data<ButtonImpl>();

    if ( button )
    {
      if (!button->_icon)
      {
        button->_icon= Gtk::manage(new Gtk::Image());
        button->_align->remove();
        button->_align->add(*button->_icon);
        button->_icon->show();
        button->_button->show_all();
      }

      if (button->_icon)
        button->_icon->set(path);
    }
  }
}



void mforms::gtk::ButtonImpl::enable_internal_padding(Button *self, bool enabled)
{
  ButtonImpl* button = self->get_data<ButtonImpl>();
  if (button)
  {
    if (enabled)
      button->_align->set_padding(0, 0, 8, 8);
    else
      button->_align->set_padding(0, 0, 0, 0);
  }
}

void mforms::gtk::ButtonImpl::init()
{
  ::mforms::ControlFactory *f = ::mforms::ControlFactory::get_instance();

  f->_button_impl.create= &ButtonImpl::create;
  f->_button_impl.set_text= &ButtonImpl::set_text;
  f->_button_impl.set_icon= &ButtonImpl::set_icon;
  f->_button_impl.enable_internal_padding= &ButtonImpl::enable_internal_padding;
}
